@@ -41,10 +41,12 @@ class iteration_tools(abc.ABC):
         # water iterations
         self.hook_route_water()
         self.route_water()
+        self.hook_after_route_water()
 
         # sediment iteration
         self.hook_route_sediment()
         self.route_sediment()
+        self.hook_after_route_sediment()
 
     def run_one_timestep(self):
         """Deprecated, since v1.3.1. Use :obj:`solve_water_and_sediment_timestep`."""
@@ -419,10 +421,11 @@ class iteration_tools(abc.ABC):
         self.log_info(_msg, verbosity=2)
         try:
             self.output_netcdf.variables[var_name][ts, :, :] = var
-        except:
-            _msg = 'Failed to save {var_name} grid to netCDF file.'.format(var_name=var_name)
+        except Exception as e:
+            _msg = (f'Failed to save {var_name} grid to netCDF file, '
+                    f'Exception: {e}')
             self.logger.error(_msg)
-            warnings.warn(UserWarning('Cannot save grid to netCDF file.'))
+            raise Exception(e)
 
     def save_the_checkpoint(self):
         """Save checkpoint files.
